@@ -1,7 +1,8 @@
+from __future__ import absolute_import
 from __future__ import print_function
 
 __author__ = 'Lei Xu <eddyxu@gmail.com>'
-__version__ = '0.1.1'
+__version__ = '0.1.2'
 
 __classifiers__ = [
     'Development Status :: 2 - Pre-Alpha',
@@ -37,7 +38,7 @@ def run():
     """Run cpp coverage."""
     import os
     import sys
-    from coveralls import coverage, report
+    from . import coverage, report
 
     args = coverage.create_args(sys.argv[1:])
 
